@@ -15,8 +15,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DRAW_INFO_H
-#define DIGIKAM_DRAW_INFO_H
+#pragma once
 
 // Qt includes
 
@@ -61,149 +60,161 @@ public:
     /**
      * Standard destructor
      */
-    ~DRawInfo();
+    ~DRawInfo() = default;
 
 public:
 
     /**
      * True if RAW file include an ICC color profile.
      */
-    bool             hasIccProfile;
+    bool             hasIccProfile          = false;
 
     /**
      * True is RAW file is decodable by dcraw.
      */
-    bool             isDecodable;
+    bool             isDecodable            = false;
 
     /**
      * The number of RAW colors.
      */
-    int              rawColors;
+    int              rawColors              = -1;
 
     /**
      * The number of RAW images.
      */
-    int              rawImages;
+    int              rawImages              = -1;
 
     /**
      * Black level from Raw histogram.
      */
-    unsigned int     blackPoint;
+    unsigned int     blackPoint             = 0;
 
     /**
      * Channel black levels from Raw histogram.
      */
-    unsigned int     blackPointCh[4];
+    unsigned int     blackPointCh[4]        = { 0 };
 
     /**
      * White level from Raw histogram.
      */
-    unsigned int     whitePoint;
+    unsigned int     whitePoint             = 0;
 
     /**
      * Top margin of raw image.
      */
-    unsigned int     topMargin;
+    unsigned int     topMargin              = 0;
 
     /**
      * Left margin of raw image.
      */
-    unsigned int     leftMargin;
+    unsigned int     leftMargin             = 0;
 
     /**
      * The raw image orientation
      */
-    ImageOrientation orientation;
+    ImageOrientation orientation            = ORIENTATION_NONE;
 
     /**
      * The sensitivity in ISO used by camera to take the picture.
      */
-    float            sensitivity;
+    float            sensitivity            = -1.0F;
 
     /**
      * 1/exposureTime = exposure time in seconds.
      */
-    float            exposureTime;
+    float            exposureTime           = -1.0F;
 
     /**
      * Aperture value in APEX.
      */
-    float            aperture;
+    float            aperture               = -1.0F;
 
     /**
      * Focal Length value in mm.
      */
-    float            focalLength;
+    float            focalLength            = -1.0F;
 
     /**
-     * The pixel Aspect Ratio if != 1.0. NOTE: if == 1.0, dcraw do not show this value.
+     * The pixel Aspect Ratio if != 1.0. NOTE: if == 1.0, libraw CLI tool do not show this value.
+     * Default value = 1.0. This can be unavailable (depending of camera model).
      */
-    float            pixelAspectRatio;
+    float            pixelAspectRatio       = 1.0F;
 
     /**
      * Exposure compensation to be applied during raw conversion.
+     * -999 is an invalid exposure.
      */
-    float            baselineExposure;
+    float            baselineExposure       = -999.0F;
 
     /**
      * Ambient temperature in Celsius degrees.
+     * -1000 is an invalid temperature.
      */
-    float            ambientTemperature;
+    float            ambientTemperature     = -1000.0F;
 
     /**
      * Ambient relative humidity in percent.
+     * -1000 is an invalid humidity.
      */
-    float            ambientHumidity;
+    float            ambientHumidity        = -1000.0F;
 
     /**
      * Ambient air pressure in hPa or mbar.
+     * -1000 is an invalid pressure.
      */
-    float            ambientPressure;
+    float            ambientPressure        = -1000.0F;
 
     /**
      * Depth under water in metres, negative for above water.
+     * 1000 is an invalid water depth.
      */
-    float            ambientWaterDepth;
+    float            ambientWaterDepth      = 1000.0F;
 
     /**
      * Directionless camera acceleration in units of mGal, or 10-5 m/s2.
+     * -1000 is an invalid acceleration.
      */
-    float            ambientAcceleration;
+    float            ambientAcceleration    = -1000.0F;
 
     /**
      * Camera elevation angle in degrees.
+     * -1000 is an invalid angle.
      */
-    float            ambientElevationAngle;
+    float            ambientElevationAngle  = -1000.0F;
 
     /**
      * Describe how flash has been used by camera.
+     * Valid value is unsigned.
      */
-    int              flashUsed;
+    int              flashUsed              = -1;
 
     /**
      * The metering mode used by camera.
+     * Valid value is unsigned.
      */
-    int              meteringMode;
+    int              meteringMode           = -1;
 
     /**
      * The exposure program used by camera.
+     * Valid value is unsigned.
      */
-    int              exposureProgram;
+    int              exposureProgram        = -1;
 
     /**
      * Exposure Index from the camera.
+     * Valid value is unsigned.
      */
-    float            exposureIndex;
+    float            exposureIndex          = -1.0F;
 
     /**
      * White color balance settings.
      */
-    double           daylightMult[3];
+    double           daylightMult[3]        = { 0.0 };
 
     /**
      * Camera multipliers used for White Balance adjustments
      */
-    double           cameraMult[4];
+    double           cameraMult[4]          = { 0.0 };
 
     /**
      * Camera Color Matrix
@@ -215,10 +226,10 @@ public:
     /**
      * GPS information
      */
-    double           latitude;
-    double           longitude;
-    double           altitude;
-    bool             hasGpsInfo;          ///< true if GPS info are parsed from RAW file.
+    double           latitude               = 0.0F;
+    double           longitude              = 0.0F;
+    double           altitude               = 0.0F;
+    bool             hasGpsInfo             = false;          ///< true if GPS info are parsed from RAW file.
 
     /**
      * The used Color Keys
@@ -258,7 +269,7 @@ public:
     /**
      * Serial number of raw image.
      */
-    unsigned int     serialNumber;
+    unsigned int     serialNumber           = 0;
 
     /**
      * The demosaising filter pattern.
@@ -341,13 +352,11 @@ public:
     QString          lensModel;
     QString          lensMake;
     QString          lensSerial;
-    int              focalLengthIn35mmFilm;
-    float            maxAperture;
+    int              focalLengthIn35mmFilm  = -1;        ///< Valid value is unsigned.
+    float            maxAperture            = -1.0F;     ///< Valid value is unsigned.
 };
 
 //! qDebug() stream operator. Writes container @a c to the debug output in a nicely formatted way.
 QDebug operator<<(QDebug dbg, const DRawInfo& c);
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DRAW_INFO_H
